@@ -54,6 +54,10 @@ CLI_CONFIG = {
         "action": "store_true",
         "help": "Output a version report for reporting bugs",
     },
+    "output": {
+        "source": "rend",
+        "default": "yaml",
+    },
 }
 
 CONFIG = {
