@@ -15,7 +15,13 @@ def load(
     """
     if not isinstance(sources, list):
         sources = [sources]
-    sources.append("pop_config")
+
+    # Load config from any project that has extended this place on the hub
+    for source in hub.config.LOAD:
+        if source not in sources:
+            # Insert at the front of the list so that these are not authoritative
+            sources.insert(0, source)
+
     if dyne_names is None:
         dyne_names = []
     raw = hub.config.dirs.load(sources, dyne_names, cli)
