@@ -25,8 +25,12 @@ def setup(hub, conf):
 
     ff = logging.Formatter(fmt=conf["log_fmt_logfile"], datefmt=conf["log_datefmt"])
     _, kwargs = hub.render.cli.args(conf["log_handler_options"])
+
+    mykwargs = {"maxBytes": 100 * 1024 * 1024, "backupCount": 5}
+    mykwargs.update(kwargs)
+
     fh = logging.handlers.RotatingFileHandler(
-        filename=conf["log_file"], delay=True, **kwargs
+        filename=conf["log_file"], delay=True, **mykwargs
     )
     fh.setLevel(hub.log.INT_LEVEL)
     fh.setFormatter(ff)
